#
# spec file for package breeze5-icons
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.55
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           breeze5-icons
Version:        5.55.0
Release:        lp151.1.17
Summary:        Breeze icon theme
License:        LGPL-3.0-only
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/breeze-icons-%{version}.tar.xz
# PATCH-FIX-OPENSUSE oxygen.diff -- inherit from oxygen
Patch0:         oxygen.diff
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
Requires:       oxygen5-icon-theme
BuildArch:      noarch

%description
Breeze-icons is a freedesktop.org compatible icon theme.

%prep
%setup -q -n breeze-icons-%{version}
%patch0 -p1
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
  %cmake_kf5 -d build -- -DBINARY_ICONS_RESOURCE=ON
  %make_jobs

%install
  %kf5_makeinstall -C build

  # yast2-theme uses these, but it got renamed in 5.55.0
  ln -s yast-software-group.svg %{buildroot}%{_kf5_iconsdir}/breeze/preferences/32/yast-software.svg
  ln -s yast-software-group.svg %{buildroot}%{_kf5_iconsdir}/breeze-dark/preferences/32/yast-software.svg

  %fdupes -s %{buildroot}%{_kf5_iconsdir}

  %icon_theme_cache_create_ghost breeze
  %icon_theme_cache_create_ghost breeze-dark

%post
%icon_theme_cache_post breeze
%icon_theme_cache_post breeze-dark

%files
%license COPYING*
%ghost %{_kf5_iconsdir}/breeze/icon-theme.cache
%ghost %{_kf5_iconsdir}/breeze-dark/icon-theme.cache
%{_kf5_iconsdir}/breeze/
%{_kf5_iconsdir}/breeze-dark/

%changelog
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Wed Feb 13 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Workaround yast2-theme incompatibility by adding a symlink
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Too many changes to list here
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Change preferences-system-network to symlink
  * Use a Kolf icon with nice background and shadows
  * Copy some changed icons from Breeze to Breeze Dark
  * Better plasma-media-center icon
  * Fix gradient positions (Breeze Dark)
  * Fix shadow gradients
  * Better desktop icon colors
  * Better multimedia related icons
  * Add YaST and new preference icons
  * Add a proper python-bytecode icon, use consistent color in python icons (kde#381051)
  * Delete python bytecode symlinks in preparation for them becoming their own icons
  * Make the python mimetype icon the base, and the python bytecode icon a link to it
  * Add device icons for RJ11 and RJ45 ports
  * Add missing directory separator (kde#401836)
  * Use correct icon for Python 3 scripts BUG: 402367 FIXED-IN: 5.54 (kde#402367)
  * Change network/web color icons to consistent style
  * Add new name for sqlite files, so the icons actually show up BUG: 402095 FIXED-IN: 5.54 (kde#402095)
  * Add drive-* icons for YaST Partitioner
  * Add view-private icon (kde#401646)
  * Add flashlight action icons
  * Improve symbolism for off and muted status icon (kde#398975)
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Add icons for application-vnd.appimage/x-iso9660-appimage
  * Add 22px dialog-warning icon (kde#397983)
  * Move firewall-applet icons to status category
  * Fix angle and margin of 32px dialog-ok-apply (kde#393608)
  * Resolve merge conflict
  * Add mouse button icons
  * Change primary monochrome icon colors to match new HIG colors
  * Change archive-* action icons to represent archives (kde#399253)
  * Add help-browser symlink to 16px and 22px directories (kde#400852)
  * Add new generic sorting icons; rename existing sorting icons
  * Added a set of Game Folder icons
  * Fix a small color and shadow issue with Kdots icon
  * Fix contrast and other small visual issues of Kdots icon
  * Create new Sublime Text icon
  * Add new icons for root
  * Add root version of drive-harddisk (kde#399307)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Change package manager icons to emblems
  * Re-add monochrome link icon as action Some action icons were symlinks to `emblem-symbolic-link`. When the new emblem style was applied to `emblem-symbolic-link`, those actions then had the wrong style. The old style has been re-added as an action icon and the symlinks have been changed to point to `link.svg`.
  * Improve emblem contrast, legibility and consistency (kde#399356, kde#399357, kde#399968)
  * Support "new" mimetype for .deb files BUG: 399421 FIXED-IN: 5.52 (kde#399421)
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Fix "stack-use-after-scope" detected by ASAN in CI
  * Fix monochrome icons missing stylesheets
  * Change drive-harddisk to more adaptable style
  * Add firewall-config and firewall-applet icons
  * Make lock on plasmavault icon visible with breeze-dark
  * Add plus symbol to document-new.svg (kde#398850)
  * Use qprintable here
  * Make it compile with KDEFrameworkCompilerSettings
  * Provide icons for 2x scaling
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Add LabPlot project file icon
  * ScalableTest, add "scalable" plasma-browser-integration (kde#393999)
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Add `drive-optical` icon (kde#396432)
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Use the broom-style icon for edit-clear-all too
  * Use a broom-style icon for edit-clear-history
  * Revert "BUG 391855 update clear icon with broom"
  * BUG 391855 update clear icon with broom
  * change 24px view-media-artist icon
* Wed Jun 13 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * fix handle-right
  * updated handles and overflow-menu
  * add varlesh to the authors list, thanks for your work
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Add plasma-browser-integration system tray icon
  * remove plasma-browser-integration system tray icon will waite for review
  * Add Virt-manager icon thanks to ndavis
  * Add video-card-inactive
  * validate icons
  * overflow-menu as view-more-symbolic, and horizontal
  * Use the more appropriate "two sliders" icon for "configure"
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Remove dupe, as was done in icons/
  * BUG:385170 add window-pin icon (kde#385170 add window-pin icon)
  * rename 64 px icons added for elisa
  * change 32px icons for playlist shuffle and repeat
  * BUG 392391 Missing icons for inline Messages BUG:392391 (kde#392391)
  * New icon for Elisa music player
  * Add media status icons
  * Remove frame around media action icons
  * autotest: skip dupetest if fdupes isn't found on Windows, to fix CI
  * add media-playlist-append and play icons
  * add view-media-album-cover for babe
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix inconsistencies in index.theme, detected by scalabletest
  * remove view-media-playlist from preferences icons
  * add 24px media-album-cover icon
  * add Babe QML support (22px)
  * update handle- icons for kirigami
  * add 64px media icons for elisa
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Too many changes to list here
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Fix icon name "weather-none" -> "weather-none-available" (kde#379875)
  * Remove obsolete reviewboardrc file
  * remove Vivaldi icon cause the origin app icon fits perfect with breeze BUG: 383517 (kde#383517)
  * add Some missing mimes
  * Breeze-icons add document-send icon BUG: 388048 (kde#388048)
  * update album artist icon
  * add labplot-editlayout support
  * remove duplicates and update dark theme
  * add gnumeric breeze-icon support
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Add missing icon sizes (kde#384473)
  * add install and uninstall for discover
  * add install and uninstall icons for discover
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix build of breeze-icons on the Android CI
  * add folder-stash for the stash Dolphin toolbar icon
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * add overflow-menu icon (kde#385171)
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * flip errow center
  * add osd icons
  * update .h and .h++ colors BUG: 376680 (kde#376680)
  * remove ktorrent small monochrome icon BUG: 381370 (kde#381370)
  * bookmarks is an action icon not a folder icon BUG: 381383 (kde#381383)
  * update utilities-system-monitor BUG: 381420 (kde#381420)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Do not depend on bash uncessarily, and do not validate icons by default.
  * add babe app icon
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * update awk mime as it's a script language BUG:376211 (kde#376211)
  * CMakeLists.txt - Do not find bash on Windows
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Add icons for hotspot (https://github.com/KDAB/hotspot)
  * icons/status/16/microphone-sensitivity-medium.svg - fix validation remove undefined inkscape:connector-curvature CC: andreas kainz <kainz.a@gmail.com>
  * BUG 377380 Better version control system icons BUG#377380
  * BUG 376780 add plasmate icon BUG:376780 (kde#376780)
  * BUG 377012 update microphone-sensitivity icons BUG:377012 (kde#377012)
  * Raise default for 'Panel' icons to 48
  * Kolourpaint Icon
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Added MIME-type icon for Dockerfile as text-dockerfile
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Added missing Plasma Vault icon
  * add a preview for the disk quota plasmoid
  * Added icons for Plasma Vault
  * Renamed the folder-*crypt icons in breeze-dark to follow breeze
  * Renamed icons for encrypted and decripted folders
  * Added arc config file
  * Rewrite tests to not use tier3 frameworks
  * add im-youtube icon for babe music player
  * update blender icons
  * Upgrade KF5 version to 5.32.0.
  * Add torrents icon 22px
  * add nm-tray icons BUG: 374672
  * color-management removed undefined links hopefully BUG: 374843
  * system-run is now an action until <= 32px and 48px an app icon BUG: 375970
  * Make tier3 dependency for tests optional
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Make BINARY_ICONS_RESOURCE ON by default
  * Add vnd.rar mime for shared-mime-info 1.7 (kde#372461)
  * Add claws icon (kde#371914)
  * Add gdrive icon instead of a generic cloud icon (kde#372111)
  * Fix bug "list-remove-symbolic use wrong image" (kde#372119)
  * Other additions and improvement
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Update kstars action icons (kde#364981)
  * Breeze Dark is listed as Breeze in System Settings wrong
    .themes file (kde#370213)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * New mimetypes icons
  * Update some kstars icons (kde#364981)
  * Wrong style actions/24/format-border-set (kde#368980)
  * Add wayland app icon
  * Add xorg app icon (kde#368813)
  * Revert distribute-randomize, view-calendar + reapply
    the transform fix (kde#367082)
  * Change folder-documents from one file to the multiple file
    cause in a folder more than one file is included (kde#368224)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Add missing namespace prefix definitions
  * Check SVG icons for wellformedness
  * Fix all edit-clear-location-ltr icons (kde#366519)
  * Add kwin effect icon support
  * Rename caps-on in input-caps-on
  * Add caps icons for text input
  * Add some gnome specific icons from Sadi58
  * Add app icons from gnastyle
  * Dolphin, Konsole and Umbrello icons optimized for 16px, 22px, 32px
  * Updated VLC icon for 22px, 32px and 48px
  * Added app icon for Subtitle Composer
  * Fix Kleopatra new icon
  * Added app icon for Kleopatra
  * Added icons for Wine and Wine-qt
  * Dix presentation word bug thanks Sadi58 (kde#358495)
  * Add system-log-out icon in 32px
  * Add 32px system- icons, remove colored system- icons
  * Add pidgin, banshee icon support
  * Remove vlc app icon due to license issue, add new VLC icon
    (kde#366490)
  * Add gthumb icon support
  * Use HighlightedText for folder icons
  * Places folder icons are now use stylesheet (highlight color)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Update mail- 16px icons to recognize the icons better
  * Update mic and audio status icons to have the same layout and size
  * New System Settings app icon
  * Add symbolic status gnome icons
  * Add gnome 3 symbolic icon support
  * Added icons for Diaspora and Vector, see phabricator.kde.org/M59
  * New icons for Dolphin and Gwenview
  * Weather icons are status icons no app icons
  * Add some links to xliff thanks gnastyle
  * Add kig icon
  * Add mimetype icons, krdc icon, other app icons from gnastyle
  * Add certificate mimetype icon (kde#365094)
  * Update gimp icons thanks gnastyle (kde#354370)
  * Globe action icon is now no linked file please use it in digikam
  * Update labplot icons according to mail 13.07. from Alexander Semke
  * Add app icons from gnastyle
  * Add kruler icon from Yuri Fabirovsky
  * Fix broken svg files thanks fuchs (kde#365035)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Many new or improved icons
  * fix kde#364931 user-idle icon was not visible
  * Add a program to convert symbolically linked files
    to qrc aliases
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Add a CMake option to build binary Qt resource out of icons dir
  * Many new and updated icons
  * update disconnect network icon for bigger diference to conntected
    (kde#353369)
  * Update mount and unmount icon (kde#358925)
  * Add some avatars from plasma-desktop/kcms/useraccount/pics/sources
  * Remove chromium icon cause the default chromium icon fit's well
    (kde#363595)
  * Make the konsole icons lighter (kde#355697)
  * Add mail icons for thunderbird (kde#357334)
  * Add public key icon (kde#361366)
  * Remove process-working-kde cause the konqueror icons should be used
    (kde#360304)
  * Update krusader icons according to (kde#359863)
  * Rename the mic icons according D1291 (kde#D1291)
  * Add some script mimetype icons (kde#363040)
  * Add virtual keyboard and touchpad on/off functionality for OSD
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Many new action and application icons.
  * Specify offered extensions as per change in kiconthemes
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Add breeze lokalize icons
  * Sync app icons between breeze and breeze dark
  * Update theme icons and remove application-system icon fix
    kicker groups
  * Add xpi support for firefox addons (kde#359913)
  * Update okular icon with the right one
  * Add ktnef app icon support
  * Add kmenueditor, kmouse and knotes icon
  * Change audio volume muted icon to use - for mute instead of
    only red color (kde#360953)
  * Add djvu mimetype support (kde#360136)
  * Add link instead of double entry
  * Add ms-shortcut icon for gnucash (kde#360776)
  * Change wallpaper background to generic one
  * Update icons to use an generic wallpaper
  * Add the icon for konqueror (kde#360304)
  * Add process-working icon for progress animation in KDE
    (kde#360304)
  * Add software install icon and update update icon
    with the right color
  * Add add and remove emblem icons for dolphin select,
    add mount icon
  * Remove stylesheet from analogclock and kickerdash applet icons
  * Sync breeze and breeze dark (kde#360294)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Many new icons
  * Add virtualbox mimetype icons and some other missing mimetypes
  * Add synaptic and octopi icon support
  * Fix cut icon (kde#354061)
  * Fix name of audio-headphones.svg (+=d)
  * Rating icons with smaller margin (1px)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Many new icons
  * Add missing mimetype icons from oxygen icon set
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Icon updates and additions
  * 22px size status icons for 32px too as you need it in the system tray
  * Changed Fixed to Scalable value to 32px folders in Breeze Dark
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Many icons added or improved
  * Use stylesheets in breeze icons (kde#126166)
  * Fix and changed system-lock-screen (kde#355902)
  * Add 24px dialog-information for GTK apps (kde#355204)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
- Drop upstreamed applets.patch
* Sun Nov 22 2015 hrvoje.senjan@gmail.com
- Added applets.patch: install applet icons (kde#355676)
* Wed Nov 18 2015 hrvoje.senjan@gmail.com
- Mark license as LGPL-3.0
- Add oxygen.diff, certain applications still expect oxygen icons
  to be present, e.g. kmail
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Breeze icons are now shipped standalone: created breeze5-icons srcpkg
